@@ -375,7 +375,7 @@ class TaskMonkClient:
         else:
             return False
 
-    def get_batch_output(self, batch_id, local_path, output_format = 'CSV', fields = []):
+    def get_batch_output(self, batch_id, local_path, output_format = 'CSV', fields = [], completed_only = False):
         """
         Parameters
         ----------
@@ -393,6 +393,9 @@ class TaskMonkClient:
             The names should match the project configuration and the headers in the input file that was used for the task upload. 
             Pass an empty string to retrieve all fields
 
+        completed_only: boolean
+            Set this flag to True to download only completed tasks in a batch. Default value for this parameter is False
+
         Returns
         -------
         str
@@ -400,8 +403,8 @@ class TaskMonkClient:
 
         """
         url = self._base_url + urlConfig.URLS['Project'] + '/v2/' + self._project_id + '/batch/' + batch_id + '/output?output_format=' + output_format
-        data = json.dumps({'field_names': fields})
-        response = apiCall.post(self.__get_token(), url,self._proxy, data, 30)
+        data = json.dumps({'field_names': fields, 'completedOnly': completed_only})
+        response = apiCall.post(self._get_token(), url,self._proxy, data, 30)
         file_url = response['file_url']
         job_id = response['job_id']
         self._wait_for_job_completion(job_id)
@@ -488,4 +491,4 @@ class TaskMonkClient:
         })
         response = apiCall.put(self.__get_token(), url,self._proxy, data, 30)
         print(response)
-        return response
\ No newline at end of file
+        return response
